文件列表 - 1165哈😂

# 文件列表

### 出自1165哈😂

这个特殊页面显示所有已上传文件。 默认设置中，最后上传的文件会显示在这个列表的顶端。

点击任一列标题可修改排序方式。
文件列表 每页显示
项
按媒体名称搜索：

日期 | 名称 | 用户 | 大小 | 描述 | 版本
--- | --- | --- | --- | --- | ---
2023年1月11日 (三) 19:05 | Screenshot_20230112025903.jpg (文件) | Saveweb | 8 KB |  | 1
2023年1月10日 (二) 14:31 | 截图_2023-01-10_22-29-18.png (文件) | Saveweb | 117 KB | (hulahula) | 1

取自“http://group0.mediawiki.demo.save-web.org/mediawiki-1.16.5/index.php?title=%E7%89%B9%E6%AE%8A:%E6%96%87%E4%BB%B6%E5%88%97%E8%A1%A8”

##### 查看

- 特殊页面

##### 个人工具

- 登录／创建账户

##### 搜索

##### 工具箱

- 特殊页面